==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/31/318da87b7a3791fca13609d5152876e9.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/Event/FormFieldEvent.php */
class __TwigTemplate_e0efa73987e0bbc1f62f0f552b826e3d extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\FormBundle\\Event;

use Mautic\\FormBundle\\Entity\\Field;
use Symfony\\Contracts\\EventDispatcher\\Event;

final class FormFieldEvent extends Event
{
    public function __construct(
        private Field \$entity,
        private bool \$isNew = false
    ) {
    }

    public function getField(): Field
    {
        return \$this->entity;
    }

    public function isNew(): bool
    {
        return \$this->isNew;
    }

    public function setField(Field \$field): void
    {
        \$this->entity = \$field;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/Event/FormFieldEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/Event/FormFieldEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/Event/FormFieldEvent.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/31/318da87b7a3791fca13609d5152876e9.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/Event/FormFieldEvent.php */
class __TwigTemplate_e0efa73987e0bbc1f62f0f552b826e3d extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\FormBundle\\Event;

use Mautic\\FormBundle\\Entity\\Field;
use Symfony\\Contracts\\EventDispatcher\\Event;

final class FormFieldEvent extends Event
{
    public function __construct(
        private Field \$entity,
        private bool \$isNew = false
    ) {
    }

    public function getField(): Field
    {
        return \$this->entity;
    }

    public function isNew(): bool
    {
        return \$this->isNew;
    }

    public function setField(Field \$field): void
    {
        \$this->entity = \$field;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/Event/FormFieldEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/Event/FormFieldEvent.php", "/var/www/html/production-demo/app/bundles/FormBundle/Event/FormFieldEvent.php");
    }
}
